////////////////////////////////////////////////////////////////////////
// Class:       SelectS1S2
// Module Type: filter
// File:        SelectS1S2_module.cc
//
// Generated at Sun Nov 24 11:14:03 2013 by alessandro razeto using artmod
// from cetpkgsupport v1_02_01.
////////////////////////////////////////////////////////////////////////

#include "art/Framework/Core/EDFilter.h"
#include "art/Framework/Core/ModuleMacros.h"
#include "art/Framework/Principal/Event.h"
#include "art/Framework/Principal/Handle.h"
#include "art/Utilities/InputTag.h"
#include "fhiclcpp/ParameterSet.h"
#include "darkmon/ArtModules/OnlineEvent.hh"

#include <memory>
#include <iostream>

namespace ds50 {
  class SelectS1S2 : public art::EDFilter {
    public:
      explicit SelectS1S2 (fhicl::ParameterSet const & p);
      virtual ~SelectS1S2 ();

      bool filter (art::Event & e) override;

    private:
      std::vector<float> start_time_s1_range_ns_, mean_s1_range_ns_, rms_s1_range_ns_;
      std::vector<float> start_time_s2_range_ns_, mean_s2_range_ns_, rms_s2_range_ns_;
      bool check_s2_peaks_;
  };
}


ds50::SelectS1S2::SelectS1S2 (fhicl::ParameterSet const &ps): 
  start_time_s1_range_ns_(ps.get<std::vector<float>> ("start_time_s1_range_ns", std::vector<float>{-250., -180.})), 
  mean_s1_range_ns_(ps.get<std::vector<float>> ("mean_s1_range_ns", std::vector<float>{0., 4000.})), 
  rms_s1_range_ns_(ps.get<std::vector<float>> ("rms_s1_range_ns", std::vector<float>{0., 3000.})), 
  start_time_s2_range_ns_(ps.get<std::vector<float>> ("start_time_s2_range_ns", std::vector<float>(0))), 
  mean_s2_range_ns_(ps.get<std::vector<float>> ("mean_s2_range_ns", std::vector<float>{4000., 100e3})), 
  rms_s2_range_ns_(ps.get<std::vector<float>> ("rms_s2_range_ns", std::vector<float>({3000., 100e3}))), 
  check_s2_peaks_(ps.get<bool> ("check_s2_peaks", false)) {}

ds50::SelectS1S2::~SelectS1S2 () {}

bool ds50::SelectS1S2::filter(art::Event & e) {
  art::Handle<ds50::Online::Clusters> clustered_event;
  e.getByLabel ("cluster", clustered_event); 
  if (!clustered_event.isValid ()) return false;

    // 2 or 3 clusters
  if (clustered_event->clusters.size () < 2 || clustered_event->clusters.size () > 3) return false;

    // S1
  if (start_time_s1_range_ns_.size () && (clustered_event->clusters[0].start_time_ns < start_time_s1_range_ns_[0] || clustered_event->clusters[0].start_time_ns > start_time_s1_range_ns_[1])) return false;

  if (mean_s1_range_ns_.size () && (clustered_event->clusters[0].mean_time_ns < mean_s1_range_ns_[0] || clustered_event->clusters[0].mean_time_ns > mean_s1_range_ns_[1])) return false;

  if (rms_s1_range_ns_.size () && (clustered_event->clusters[0].rms_time_ns < rms_s1_range_ns_[0] || clustered_event->clusters[0].rms_time_ns > rms_s1_range_ns_[1])) return false;

  if (clustered_event->clusters[0].peaks.size () != 1) return false;
  
    // S2
  if (start_time_s2_range_ns_.size () && (clustered_event->clusters[1].start_time_ns < start_time_s2_range_ns_[0] || clustered_event->clusters[1].start_time_ns > start_time_s2_range_ns_[1])) return false;

  if (mean_s2_range_ns_.size () && (clustered_event->clusters[1].mean_time_ns < mean_s2_range_ns_[0] || clustered_event->clusters[1].mean_time_ns > mean_s2_range_ns_[1])) return false;

  if (rms_s2_range_ns_.size () && (clustered_event->clusters[1].rms_time_ns < rms_s2_range_ns_[0] || clustered_event->clusters[1].rms_time_ns > rms_s2_range_ns_[1])) return false;
  
  if (check_s2_peaks_ && clustered_event->clusters[1].peaks.size () != 1) return false;

  return true;
}

DEFINE_ART_MODULE(ds50::SelectS1S2)
